/**********************************************************************/
/* MQINIT:  Initialize MQ Instrumentation                             */
/* -- Discovery MQ Queue Managers                                     */
/* -- Register each manager as a GEM component                        */
/* -- Save each ComponentId in a global variable                      */
/* -- Instantiate a job monitor for each queue manager                */
/**********************************************************************/

/**********************************************************************/
/* Heartbeat interval is passed as a parameter.                       */
/**********************************************************************/
Parse arg MQ_HB_INTERVAL hostname .
If MQ_HB_INTERVAL = '' Then
  MQ_HB_INTERVAL = 360

'GLOBALV PUTC MQ_HB_INTERVAL'

/**********************************************************************/
/* Get hostname.  If it does not exist, just use NetView domain name  */
/* as a system unique origin value.                                   */
/**********************************************************************/
If hostname = '' Then Do
  'GLOBALV GETC DSIAPM_TCP_HOSTNAME'
  If DSIAPM_TCP_HOSTNAME = '' Then Do
    'GLOBALV GETC DSIAPM_DOMAIN'
    hostname = DSIAPM_DOMAIN
  End                                    /* If                        */
  Else
    hostname = DSIAPM_TCP_HOSTNAME
End

/**********************************************************************/
/* List all MQ subsystems.  Note that the discovery command is        */
/* shipped via PTF as DSILSSS.  The MQ manager ships the same code    */
/* separately as IHSMDSCV.  Sample output:                            */
/* BNH532I SUBSYSTEM LIST                                             */
/* BNH533I CSQ1 ERLY CSQ1 CSQ1MSTR CSQ3EPX  569513700 +CSQ1           */
/* BNH533I CSQ2 ERLY CSQ2 CSQ2MSTR CSQ3EPX  569513700 +CSQ2           */
/* BNH533I CSQ3 ERLY CSQ3 CSQ3MSTR CSQ3EPX  569513700 +CSQ3           */
/* BNH533I CSQ4 ERLY CSQ4 CSQ4MSTR CSQ3EPX  569513700 +CSQ4           */
/* BNH533I CSQ5 ERLY CSQ5 CSQ5MSTR CSQ3EPX  569513700 +CSQ5           */
/* BNH534I END SUBSYSTEM LIST                                         */
/**********************************************************************/
'PIPE NETV DSILSSS | SEP | LOC /CSQ3EPX/ | STEM RSP.'

/**********************************************************************/
/* For each subsystem, register a GEM component and instantiate a job */
/* monitor.                                                           */
/**********************************************************************/
CID_count = 0                            /* Initialize count of
                                            ComponentIds              */
source = 'IBM;MQSeries;2.2.1'
subsource = 'IBM;MQSQMgr;2.2.1'
origin = '0=host=' || hostname

Do I = 1 to RSP.0
  Parse Var RSP.I . subsystem . . jobname .

  display_name = subsystem || '@' || hostname
  suborigin = '0=MQSQMgr=' || display_name

  ComponentId = GEMREG("S='"  || source || "'",
                       "SS='" || subsource || "'",
                       "O='"  || origin || "'",
                       "SO='" || suborigin || "'",
                       "DN='" || display_name || "'")

  Parse var ComponentId 'CID' cid_num
  If datatype(cid_num,'W') Then Do       /* If GEMREG successful      */
    /******************************************************************/
    /* Save ComponentId.                                              */
    /******************************************************************/
    CID_count = CID_count + 1
    MQ_COMP_LIST.CID_count = ComponentId
    'GLOBALV PUTC MQ_COMP_LIST.' || CID_count

    /******************************************************************/
    /* Instantiate job monitor.                                       */
    /******************************************************************/
    ret_code = GEMMJOB(ComponentId "'STATE'" jobname)

    /******************************************************************/
    /* Set Threshold can be issued to change the severity of          */
    /* threshold events for the state monitor.                        */
    /******************************************************************/
    /* Call GEMSETTH(ComponentId "'STATE' UP,6,0,DOWN,6,4 EVENT") */

  End                                    /* If datatype               */
End                                      /* Do I                      */

/**********************************************************************/
/* Save count of ComponentIds                                         */
/**********************************************************************/
MQ_COMP_LIST.0 = CID_count
'GLOBALV PUTC MQ_COMP_LIST.0'

/**********************************************************************/
/* Set heartbeat timer                                                */
/**********************************************************************/
minutes = MQ_HB_INTERVAL // 60           /* Minutes component         */
hours = trunc(MQ_HB_INTERVAL / 60)       /* Hours component           */

'PURGE TIMER=MQHB,OP=AUTOAMI'            /* Cancel existing timer     */
'EXCMD AUTOAMI EVERY' hours || ':' || minutes || ':00,ID=MQHB,MQHB'

'MQHB'                                   /* Send initial heartbeats   */

Call GEMJMVR                             /* Send initial threshold
                                            events                    */
Exit 0